# emflow: Energy Modelling Flow
### Enabling flow of mind to model flow of energy

As energy systems world-wide continue to decarbonise through deployment of renewable and fossil-free energy, they are also becoming more intermittent and complex. We need better data-driven methods to handle this complexity, with `python` rapidly becoming the tool-of-choice for energy modellers. 

1. **Occam’s Razor / Keep It Simple, Stupid (KISS):** the best solution is usually also the simplest one. Over-engineering is the root of all evil. 
2. **Community-first:** Iterate tightly with the ecosystem and community of energy modelers to understand and find the best solution. 
3. **People-first:** Making code explicit, readable and intuitive counts. “Programs are meant to be read by humans and only incidentally for computers to execute”.

## TL;DR
# Check in https://github.com/Significant-Gravitas/AutoGPT (use more emojis)
# Could we have some sort of picture here in the beginning? E.g. mindsdb

## Purpose and philosophy
Write about that it is the connection with energydatamodel

Run your high-level Keras workflows on top of any framework -- benefiting at will from the advantages of each framework, e.g. the scalability and performance of JAX or the production ecosystem options of TensorFlow.
Write custom components (e.g. layers, models, metrics) that you can use in low-level workflows in any framework.
You can take a Keras model and train it in a training loop written from scratch in native TF, JAX, or PyTorch.
You can take a Keras model and use it as part of a PyTorch-native Module or as part of a JAX-native model function.
Make your ML code future-proof by avoiding framework lock-in.
As a PyTorch user: get access to power and usability of Keras, at last!
As a JAX user: get access to a fully-featured, battle-tested, well-documented modeling and training library.
Read more in the Keras 3 release announcement.

## Getting started 
### Installation
### Simple example / Quickstart
## Documentation
## Relation to rebase.energy
